using System;
using System.IO;
using System.Text.Encodings.Web;
using System.Text.Unicode;
using Falcon.Extend;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Redis;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.OpenApi.Models;
using StaffManagement.Database;
using StaffManagement.Extensions;

namespace StaffManagement
{
    public class Startup
    {
        public Startup(IConfiguration configuration) {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        public void ConfigureServices(IServiceCollection services) {
            //עJsonл
            services.AddMsJsonProvider();
            //עݿ
            var dbStr = this.Configuration.GetValue<string>("Database:dbConnStr");
            services.AddDbContext<SMDbContext>(option => {
                option.UseMySql(dbStr);
            });
            //עRedis
            var rop = this.Configuration.GetSection("Redis").Get<RedisCacheOptions>();
            services.AddRedis(rop);
            //עỺ
            services.AddSingleton<CacheHelper>();
            //עMVC
            services.AddControllersWithViews()
                .AddJsonOptions(option => {
                    option.JsonSerializerOptions.Encoder = JavaScriptEncoder.Create(UnicodeRanges.All);
                    option.JsonSerializerOptions.PropertyNamingPolicy = null;
                });

            //עSwagger
            services.AddSwaggerGen(c => {
                c.SwaggerDoc("V1",new OpenApiInfo {
                    Title = "ԱAPIӿ",// option.GetValue<string>("Title"),
                    Version = "1.0",
                    Description = "ͳһAPIӿƣ鿴ϸӿڹ淶",
                });
                var basePath = AppContext.BaseDirectory;
                c.IncludeXmlComments(Path.Combine(basePath,"StaffManagement.xml"),true);
                c.AddXmlEnumEnable(Path.Combine(basePath,"StaffManagement.xml"));
            });
            //עapi
            services.AddScoped<ApiExceptionFilterAttribute>();
        }

        public void Configure(IApplicationBuilder app,IWebHostEnvironment env,SMDbContext db) {
            if(env.IsDevelopment()) {
                app.UseDeveloperExceptionPage();
            } else {
                app.UseExceptionHandler("/Home/Error");
            }
            app.UseStaticFiles();
            db.Database.EnsureCreated();
            app.UseSwagger();
            app.UseSwaggerUI(c => {
                c.SwaggerEndpoint("/swagger/V1/swagger.json","ӿĵ");
                c.RoutePrefix = "api";
                c.DocumentTitle = "һվʽҽƾӿĵ";
                c.InjectStylesheet("/css/swagger.css");
                c.InjectJavascript("/lib/jquery/dist/jquery.min.js");
                c.InjectJavascript("/js/swagger.js");
            });


            app.UseRouting();

            app.UseAuthorization();

            app.UseEndpoints(endpoints => {
                endpoints.MapControllerRoute(
                    name: "default",
                    pattern: "{controller=Home}/{action=Index}/{id?}");
            });
        }
    }
}
